==> eiffelstudio-18.07.10.1981.tar: F_code/C1/ew38.c <==
/*
 * Code for class EW_C_COMPILE_RESULT_INST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew38.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_C_COMPILE_RESULT_INST}.inst_initialize */
void F50_656 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,loc2);
	RTLR(4,tr1);
	RTLR(5,loc3);
	RTLIU(6);
	
	RTEAA("inst_initialize", 49, Current, 3, 1, 719);
	RTGC;
	RTHOOK(1);
	loc1 = F38_569(Current, arg1);
	RTHOOK(2);
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R1422[Dtype(loc1)-417])(RTCW(loc1));
	if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 1L))) {
		RTHOOK(3);
		ti4_1 = ((EIF_INTEGER_32) 1L);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R1442[Dtype(loc1)-560])(RTCW(loc1), (EIF_REFERENCE) &ti4_1);
		loc2 = F890_5571(RTCW(tr1));
		RTHOOK(4);
		tr1 = RTMS32_EX_H("o\000\000\000k\000\000\000",2,28523);
		tb1 = F893_5666(RTCW(loc2), tr1);
		if (tb1) {
			RTHOOK(5);
			tr1 = RTLNS(eif_new_type(142, 0x00).id, 142, _OBJSIZ_0_2_0_0_0_0_0_0_);
			loc3 = (EIF_REFERENCE) tr1;
			RTHOOK(6);
			F143_1467(RTCW(loc3), (EIF_BOOLEAN) 1);
			RTHOOK(7);
			RTAR(Current, loc3);
			*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) loc3;
			RTHOOK(8);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		} else {
			RTHOOK(9);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
			RTHOOK(10);
			tr1 = RTMS32_EX_H("u\000\000\000n\000\000\000k\000\000\000n\000\000\000o\000\000\000w\000\000\000n\000\000\000 \000\000\000k\000\000\000e\000\000\000y\000\000\000w\000\000\000o\000\000\000r\000\000\000d\000\000\000:\000\000\000 \000\000\000",17,704718112);
			tr1 = F895_5757(tr1, loc2);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		}
	} else {
		RTHOOK(11);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
		RTHOOK(12);
		tr1 = RTMS32_EX_H("e\000\000\000x\000\000\000a\000\000\000c\000\000\000t\000\000\000l\000\000\000y\000\000\000 \000\000\000o\000\000\000n\000\000\000e\000\000\000 \000\000\000a\000\000\000r\000\000\000g\000\000\000u\000\000\000m\000\000\000e\000\000\000n\000\000\000t\000\000\000 \000\000\000r\000\000\000e\000\000\000q\000\000\000u\000\000\000i\000\000\000r\000\000\000e\000\000\000d\000\000\000",29,1291677796);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	RTHOOK(13);
	RTLE;
	RTEE;
}

/* {EW_C_COMPILE_RESULT_INST}.execute */
void F50_657 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTEAA("execute", 49, Current, 1, 1, 720);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_10_);
	RTHOOK(2);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		RTHOOK(3);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
		RTHOOK(4);
		tr1 = RTMS32_EX_H("n\000\000\000o\000\000\000 \000\000\000p\000\000\000e\000\000\000n\000\000\000d\000\000\000i\000\000\000n\000\000\000g\000\000\000 \000\000\000C\000\000\000 \000\000\000c\000\000\000o\000\000\000m\000\000\000p\000\000\000i\000\000\000l\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000 \000\000\000r\000\000\000e\000\000\000s\000\000\000u\000\000\000l\000\000\000t\000\000\000 \000\000\000t\000\000\000o\000\000\000 \000\000\000c\000\000\000h\000\000\000e\000\000\000c\000\000\000k\000\000\000",40,922861931);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(5);
		tb1 = F143_1469(RTCW(loc1), *(EIF_REFERENCE *)(Current + _REFACS_6_));
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_) = (EIF_BOOLEAN) tb1;
		RTHOOK(6);
		if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_)) {
			RTHOOK(7);
			tr1 = RTMS32_EX_H("a\000\000\000c\000\000\000t\000\000\000u\000\000\000a\000\000\000l\000\000\000 \000\000\000C\000\000\000 \000\000\000c\000\000\000o\000\000\000m\000\000\000p\000\000\000i\000\000\000l\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000 \000\000\000r\000\000\000e\000\000\000s\000\000\000u\000\000\000l\000\000\000t\000\000\000 \000\000\000d\000\000\000o\000\000\000e\000\000\000s\000\000\000 \000\000\000n\000\000\000o\000\000\000t\000\000\000 \000\000\000m\000\000\000a\000\000\000t\000\000\000c\000\000\000h\000\000\000 \000\000\000e\000\000\000x\000\000\000p\000\000\000e\000\000\000c\000\000\000t\000\000\000e\000\000\000d\000\000\000 \000\000\000r\000\000\000e\000\000\000s\000\000\000u\000\000\000l\000\000\000t\000\000\000\012\000\000\000",59,2135351818);
			tr2 = RTMS_EX_H("Actual result: ",15,1538353696);
			tr1 = F895_5757(tr1, tr2);
			tr2 = F143_1466(RTCW(loc1));
			tr1 = F895_5757(RTCW(tr1), tr2);
			tr2 = RTMS_EX_H("\012Expected result: ",18,1571576608);
			tr1 = F895_5757(RTCW(tr1), tr2);
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			tr2 = F143_1466(RTCW(tr2));
			tr1 = F895_5757(RTCW(tr1), tr2);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		}
		RTHOOK(8);
		F906_6170(RTCW(arg1), NULL);
	}
	RTHOOK(9);
	RTLE;
	RTEE;
}

/* {EW_C_COMPILE_RESULT_INST}.init_ok */
EIF_BOOLEAN F50_658 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_);
}


/* {EW_C_COMPILE_RESULT_INST}.execute_ok */
EIF_BOOLEAN F50_659 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_);
}


/* {EW_C_COMPILE_RESULT_INST}.expected_compile_result */
EIF_REFERENCE F50_660 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


void EIF_Minit38 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C1/ew38.c <==
/*
 * Code for class EW_C_COMPILE_RESULT_INST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew38.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_C_COMPILE_RESULT_INST}.inst_initialize */
void F50_674 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,loc2);
	RTLR(4,tr1);
	RTLR(5,loc3);
	RTLIU(6);
	
	RTEAA("inst_initialize", 49, Current, 3, 1, 737);
	RTGC;
	RTHOOK(1);
	loc1 = F38_587(Current, arg1);
	RTHOOK(2);
	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2568[Dtype(RTCW(loc1))-536])(loc1);
	if ((EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 1L))) {
		RTHOOK(3);
		ti4_1 = ((EIF_INTEGER_32) 1L);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R2588[Dtype(RTCW(loc1))-563])(loc1, (EIF_REFERENCE) &ti4_1);
		loc2 = F892_5631(RTCW(tr1));
		RTHOOK(4);
		tr1 = RTMS32_EX_H("o\000\000\000k\000\000\000",2,28523);
		tb1 = F895_5726(RTCW(loc2), tr1);
		if (tb1) {
			RTHOOK(5);
			loc3 = RTLNS(eif_new_type(143, 0x00).id, 143, _OBJSIZ_0_2_0_0_0_0_0_0_);
			RTHOOK(6);
			F144_1499(RTCW(loc3), (EIF_BOOLEAN) 1);
			RTHOOK(7);
			RTAR(Current, loc3);
			*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) loc3;
			RTHOOK(8);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		} else {
			RTHOOK(9);
			*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
			RTHOOK(10);
			tr1 = RTMS32_EX_H("u\000\000\000n\000\000\000k\000\000\000n\000\000\000o\000\000\000w\000\000\000n\000\000\000 \000\000\000k\000\000\000e\000\000\000y\000\000\000w\000\000\000o\000\000\000r\000\000\000d\000\000\000:\000\000\000 \000\000\000",17,704718112);
			tr1 = F897_5817(tr1, loc2);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		}
	} else {
		RTHOOK(11);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
		RTHOOK(12);
		tr1 = RTMS32_EX_H("e\000\000\000x\000\000\000a\000\000\000c\000\000\000t\000\000\000l\000\000\000y\000\000\000 \000\000\000o\000\000\000n\000\000\000e\000\000\000 \000\000\000a\000\000\000r\000\000\000g\000\000\000u\000\000\000m\000\000\000e\000\000\000n\000\000\000t\000\000\000 \000\000\000r\000\000\000e\000\000\000q\000\000\000u\000\000\000i\000\000\000r\000\000\000e\000\000\000d\000\000\000",29,1291677796);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	}
	RTHOOK(13);
	RTLE;
	RTEE;
}

/* {EW_C_COMPILE_RESULT_INST}.execute */
void F50_675 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,loc1);
	RTLR(1,arg1);
	RTLR(2,Current);
	RTLR(3,tr1);
	RTLR(4,tr2);
	RTLIU(5);
	
	RTEAA("execute", 49, Current, 1, 1, 738);
	RTGC;
	RTHOOK(1);
	loc1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_10_);
	RTHOOK(2);
	if ((EIF_BOOLEAN)(loc1 == NULL)) {
		RTHOOK(3);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
		RTHOOK(4);
		tr1 = RTMS32_EX_H("n\000\000\000o\000\000\000 \000\000\000p\000\000\000e\000\000\000n\000\000\000d\000\000\000i\000\000\000n\000\000\000g\000\000\000 \000\000\000C\000\000\000 \000\000\000c\000\000\000o\000\000\000m\000\000\000p\000\000\000i\000\000\000l\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000 \000\000\000r\000\000\000e\000\000\000s\000\000\000u\000\000\000l\000\000\000t\000\000\000 \000\000\000t\000\000\000o\000\000\000 \000\000\000c\000\000\000h\000\000\000e\000\000\000c\000\000\000k\000\000\000",40,922861931);
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	} else {
		RTHOOK(5);
		tb1 = F144_1501(RTCW(loc1), *(EIF_REFERENCE *)(Current + _REFACS_6_));
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_) = (EIF_BOOLEAN) tb1;
		RTHOOK(6);
		if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_)) {
			RTHOOK(7);
			tr1 = RTMS32_EX_H("a\000\000\000c\000\000\000t\000\000\000u\000\000\000a\000\000\000l\000\000\000 \000\000\000C\000\000\000 \000\000\000c\000\000\000o\000\000\000m\000\000\000p\000\000\000i\000\000\000l\000\000\000a\000\000\000t\000\000\000i\000\000\000o\000\000\000n\000\000\000 \000\000\000r\000\000\000e\000\000\000s\000\000\000u\000\000\000l\000\000\000t\000\000\000 \000\000\000d\000\000\000o\000\000\000e\000\000\000s\000\000\000 \000\000\000n\000\000\000o\000\000\000t\000\000\000 \000\000\000m\000\000\000a\000\000\000t\000\000\000c\000\000\000h\000\000\000 \000\000\000e\000\000\000x\000\000\000p\000\000\000e\000\000\000c\000\000\000t\000\000\000e\000\000\000d\000\000\000 \000\000\000r\000\000\000e\000\000\000s\000\000\000u\000\000\000l\000\000\000t\000\000\000\012\000\000\000",59,2135351818);
			tr2 = RTMS_EX_H("Actual result: ",15,1538353696);
			tr1 = F897_5817(tr1, tr2);
			tr2 = F144_1498(RTCW(loc1));
			tr1 = F897_5817(RTCW(tr1), tr2);
			tr2 = RTMS_EX_H("\012Expected result: ",18,1571576608);
			tr1 = F897_5817(RTCW(tr1), tr2);
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
			tr2 = F144_1498(RTCW(tr2));
			tr1 = F897_5817(RTCW(tr1), tr2);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
		}
		RTHOOK(8);
		F908_6231(RTCW(arg1), NULL);
	}
	RTHOOK(9);
	RTLE;
	RTEE;
}

/* {EW_C_COMPILE_RESULT_INST}.init_ok */
EIF_BOOLEAN F50_676 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_);
}


/* {EW_C_COMPILE_RESULT_INST}.execute_ok */
EIF_BOOLEAN F50_677 (EIF_REFERENCE Current)
{
	return *(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_);
}


void EIF_Minit38 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
